@@ -12,6 +12,7 @@
 #    WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 #    License for the specific language governing permissions and limitations
 #    under the License.
+import collections
 import logging
 import pkg_resources
 import requests
@@ -55,6 +56,49 @@ class ProtocolFeaturesSupportedField(base.CompositeField):
     """The select query parameter is supported"""
 
 
+class LazyRegistries(collections.MutableMapping):
+    """Download registries on demand.
+
+    Redfish message registries can be very large. On top of that,
+    they are not used frequently. Thus, let's not pull them off
+    the BMC unless the consumer is actually trying to use them.
+
+    :param service_root: Redfish service root object
+    :type service_root: Sushy
+    """
+
+    def __init__(self, service_root):
+        self._service_root = service_root
+        self._registries = None
+
+    def __getitem__(self, key):
+        registries = self.registries
+        return registries[key]
+
+    def __setitem__(self, key, value):
+        registries = self.registries
+        registries[key] = value
+
+    def __delitem__(self, key):
+        registries = self.registries
+        del registries[key]
+
+    def __iter__(self):
+        registries = self.registries
+        return iter(registries or ())
+
+    def __len__(self):
+        registries = self.registries
+        return len(registries)
+
+    @property
+    def registries(self):
+        if self._registries is None:
+            self._registries = self._service_root.registries
+
+        return self._registries
+
+
 class Sushy(base.ResourceBase):
 
     identity = base.Field('Id', required=True)
@@ -127,8 +171,8 @@ class Sushy(base.ResourceBase):
             Defaults to 'en'.
         """
         self._root_prefix = root_prefix
-        if (auth is not None and (password is not None or
-                                  username is not None)):
+        if (auth is not None and (password is not None
+                                  or username is not None)):
             msg = ('Username or Password were provided to Sushy '
                    'when an authentication mechanism was specified.')
             raise ValueError(msg)
@@ -180,7 +224,7 @@ class Sushy(base.ResourceBase):
         return system.SystemCollection(
             self._conn, self._systems_path,
             redfish_version=self.redfish_version,
-            registries=self.registries)
+            registries=self.lazy_registries)
 
     def get_system(self, identity=None):
         """Given the identity return a System object
@@ -203,7 +247,7 @@ class Sushy(base.ResourceBase):
 
         return system.System(self._conn, identity,
                              redfish_version=self.redfish_version,
-                             registries=self.registries)
+                             registries=self.lazy_registries)
 
     def get_chassis_collection(self):
         """Get the ChassisCollection object
@@ -218,7 +262,7 @@ class Sushy(base.ResourceBase):
 
         return chassis.ChassisCollection(self._conn, self._chassis_path,
                                          redfish_version=self.redfish_version,
-                                         registries=self.registries)
+                                         registries=self.lazy_registries)
 
     def get_chassis(self, identity=None):
         """Given the identity return a Chassis object
@@ -241,7 +285,7 @@ class Sushy(base.ResourceBase):
 
         return chassis.Chassis(self._conn, identity,
                                redfish_version=self.redfish_version,
-                               registries=self.registries)
+                               registries=self.lazy_registries)
 
     def get_fabric_collection(self):
         """Get the FabricCollection object
@@ -256,7 +300,7 @@ class Sushy(base.ResourceBase):
 
         return fabric.FabricCollection(self._conn, self._fabrics_path,
                                        redfish_version=self.redfish_version,
-                                       registries=self.registries)
+                                       registries=self.lazy_registries)
 
     def get_fabric(self, identity):
         """Given the identity return a Fabric object
@@ -266,7 +310,7 @@ class Sushy(base.ResourceBase):
         """
         return fabric.Fabric(self._conn, identity,
                              redfish_version=self.redfish_version,
-                             registries=self.registries)
+                             registries=self.lazy_registries)
 
     def get_manager_collection(self):
         """Get the ManagerCollection object
@@ -281,7 +325,7 @@ class Sushy(base.ResourceBase):
 
         return manager.ManagerCollection(self._conn, self._managers_path,
                                          redfish_version=self.redfish_version,
-                                         registries=self.registries)
+                                         registries=self.lazy_registries)
 
     def get_manager(self, identity=None):
         """Given the identity return a Manager object
@@ -303,7 +347,7 @@ class Sushy(base.ResourceBase):
 
         return manager.Manager(self._conn, identity,
                                redfish_version=self.redfish_version,
-                               registries=self.registries)
+                               registries=self.lazy_registries)
 
     def get_session_service(self):
         """Get the SessionService object
@@ -328,7 +372,8 @@ class Sushy(base.ResourceBase):
         """
         return session.Session(
             self._conn, identity,
-            redfish_version=self.redfish_version, registries=self.registries)
+            redfish_version=self.redfish_version,
+            registries=self.lazy_registries)
 
     def get_update_service(self):
         """Get the UpdateService object
@@ -342,7 +387,7 @@ class Sushy(base.ResourceBase):
         return updateservice.UpdateService(
             self._conn, self._update_service_path,
             redfish_version=self.redfish_version,
-            registries=self.registries)
+            registries=self.lazy_registries)
 
     def _get_registry_collection(self):
         """Get MessageRegistryFileCollection object
@@ -374,7 +419,7 @@ class Sushy(base.ResourceBase):
         return compositionservice.CompositionService(
             self._conn, self._composition_service_path,
             redfish_version=self.redfish_version,
-            registries=self.registries)
+            registries=self.lazy_registries)
 
     def _get_standard_message_registry_collection(self):
         """Load packaged standard message registries
@@ -385,12 +430,13 @@ class Sushy(base.ResourceBase):
         message_registries = []
         resource_package_name = __name__
         for json_file in pkg_resources.resource_listdir(
-            resource_package_name, STANDARD_REGISTRY_PATH):
-                # Not using path.join according to pkg_resources docs
-                mes_reg = message_registry.MessageRegistry(
-                    None, STANDARD_REGISTRY_PATH + json_file,
-                    reader=base.JsonPackagedFileReader(resource_package_name))
-                message_registries.append(mes_reg)
+                resource_package_name, STANDARD_REGISTRY_PATH):
+            # Not using path.join according to pkg_resources docs
+            mes_reg = message_registry.MessageRegistry(
+                None, STANDARD_REGISTRY_PATH + json_file,
+                reader=base.JsonPackagedFileReader(
+                    resource_package_name))
+            message_registries.append(mes_reg)
 
         return message_registries
 
@@ -408,8 +454,8 @@ class Sushy(base.ResourceBase):
         """
         standard = self._get_standard_message_registry_collection()
 
-        registries = {r.registry_prefix + '.' +
-                      r.registry_version.rsplit('.', 1)[0]: r
+        registries = {r.registry_prefix + '.'
+                      + r.registry_version.rsplit('.', 1)[0]: r
                       for r in standard if r.language == self._language}
 
         registry_col = self._get_registry_collection()
@@ -421,3 +467,16 @@ class Sushy(base.ResourceBase):
                                self._public_connector) for r in provided})
 
         return registries
+
+    @property
+    def lazy_registries(self):
+        """Gets and combines all message registries together
+
+        Fetches all registries if any provided by Redfish service
+        and combines together with packaged standard registries.
+
+        :returns: dict of combined message registries where key is
+            Registry_name.Major_version.Minor_version and value is registry
+            itself.
+        """
+        return LazyRegistries(self)
