@@ -13,6 +13,7 @@
 # This is referred from Redfish standard schema.
 # https://redfish.dmtf.org/schemas/Bios.v1_0_3.json
 
+from http import client as http_client
 import logging
 
 from sushy import exceptions
@@ -31,9 +32,7 @@ class ActionsField(base.CompositeField):
 
 class Bios(base.ResourceBase):
 
-    def __init__(self, connector, path, registries, *args, **kwargs):
-        super(Bios, self).__init__(connector, path, *args, **kwargs)
-        self._registries = registries
+    def __init__(self, connector, path, redfish_version=None, registries=None):
         """A class representing a Bios
 
         :param connector: A Connector instance
@@ -41,6 +40,8 @@ class Bios(base.ResourceBase):
         :param registries: Dict of message registries to be used when
             parsing messages of attribute update status
         """
+        super(Bios, self).__init__(
+            connector, path, redfish_version, registries)
 
     identity = base.Field('Id', required=True)
     """The Bios resource identity string"""
@@ -152,7 +153,15 @@ class Bios(base.ResourceBase):
         target_uri = self._get_reset_bios_action_element().target_uri
 
         LOG.debug('Resetting BIOS attributes %s ...', self.identity)
-        self._conn.post(target_uri)
+        try:
+            self._conn.post(target_uri)
+        except exceptions.HTTPError as resp:
+            # Send empty payload, if BMC expects body
+            if resp.status_code == http_client.UNSUPPORTED_MEDIA_TYPE:
+                self._conn.post(target_uri, data={})
+            else:
+                raise
+
         LOG.info('BIOS attributes %s is being reset', self.identity)
 
     def change_password(self, new_password, old_password, password_name):
