@@ -95,32 +95,32 @@ class MainTestCase(base.TestCase):
         self.assertFalse(mock_Sushy_Connector.called)
 
     @mock.patch.object(system, 'SystemCollection', autospec=True)
-    @mock.patch('sushy.Sushy.registries', autospec=True)
+    @mock.patch('sushy.Sushy.lazy_registries', autospec=True)
     def test_get_system_collection(
-            self, mock_registries, mock_system_collection):
+            self, mock_lazy_registries, mock_system_collection):
         self.root._standard_message_registries_path = None
         self.root.get_system_collection()
         mock_system_collection.assert_called_once_with(
             self.root._conn, '/redfish/v1/Systems',
             redfish_version=self.root.redfish_version,
-            registries=mock_registries
+            registries=mock_lazy_registries
         )
 
     @mock.patch.object(system, 'System', autospec=True)
-    @mock.patch('sushy.Sushy.registries', autospec=True)
-    def test_get_system(self, mock_registries, mock_system):
+    @mock.patch('sushy.Sushy.lazy_registries', autospec=True)
+    def test_get_system(self, mock_lazy_registries, mock_system):
         self.root._standard_message_registries_path = None
         self.root.get_system('fake-system-id')
         mock_system.assert_called_once_with(
             self.root._conn, 'fake-system-id',
             redfish_version=self.root.redfish_version,
-            registries=mock_registries)
+            registries=mock_lazy_registries)
 
     @mock.patch.object(system, 'SystemCollection', autospec=True)
     @mock.patch.object(system, 'System', autospec=True)
-    @mock.patch('sushy.Sushy.registries', autospec=True)
+    @mock.patch('sushy.Sushy.lazy_registries', autospec=True)
     def test_get_system_default_ok(
-            self, mock_registries, mock_system, mock_system_collection):
+            self, mock_lazy_registries, mock_system, mock_system_collection):
         self.root._standard_message_registries_path = None
         mock_system.path = 'fake-system-id'
         mock_members = mock_system_collection.return_value.get_members
@@ -129,18 +129,18 @@ class MainTestCase(base.TestCase):
         mock_system_collection.assert_called_once_with(
             self.root._conn, '/redfish/v1/Systems',
             redfish_version=self.root.redfish_version,
-            registries=mock_registries
+            registries=mock_lazy_registries
         )
         mock_system.assert_called_once_with(
             self.root._conn, 'fake-system-id',
             redfish_version=self.root.redfish_version,
-            registries=mock_registries)
+            registries=mock_lazy_registries)
 
     @mock.patch.object(system, 'SystemCollection', autospec=True)
     @mock.patch.object(system, 'System', autospec=True)
-    @mock.patch('sushy.Sushy.registries', autospec=True)
+    @mock.patch('sushy.Sushy.lazy_registries', autospec=True)
     def test_get_system_default_failure(
-            self, mock_registries, mock_system, mock_system_collection):
+            self, mock_lazy_registries, mock_system, mock_system_collection):
         self.root._standard_message_registries_path = None
         mock_members = mock_system_collection.return_value.get_members
         mock_members.return_value = []
@@ -148,7 +148,7 @@ class MainTestCase(base.TestCase):
         mock_system_collection.assert_called_once_with(
             self.root._conn, '/redfish/v1/Systems',
             redfish_version=self.root.redfish_version,
-            registries=mock_registries
+            registries=mock_lazy_registries
         )
 
     @mock.patch.object(chassis, 'Chassis', autospec=True)
@@ -156,13 +156,13 @@ class MainTestCase(base.TestCase):
         self.root.get_chassis('fake-chassis-id')
         mock_chassis.assert_called_once_with(
             self.root._conn, 'fake-chassis-id',
-            self.root.redfish_version, self.root.registries)
+            self.root.redfish_version, self.root.lazy_registries)
 
     @mock.patch.object(chassis, 'ChassisCollection', autospec=True)
     @mock.patch.object(chassis, 'Chassis', autospec=True)
-    @mock.patch('sushy.Sushy.registries', autospec=True)
+    @mock.patch('sushy.Sushy.lazy_registries', autospec=True)
     def test_get_chassis_default_ok(
-            self, mock_registries, mock_chassis, mock_chassis_collection):
+            self, mock_lazy_registries, mock_chassis, mock_chassis_collection):
         self.root._standard_message_registries_path = None
         mock_chassis.path = 'fake-chassis-id'
         mock_members = mock_chassis_collection.return_value.get_members
@@ -171,19 +171,19 @@ class MainTestCase(base.TestCase):
         mock_chassis_collection.assert_called_once_with(
             self.root._conn, '/redfish/v1/Chassis',
             redfish_version=self.root.redfish_version,
-            registries=mock_registries
+            registries=mock_lazy_registries
         )
         mock_chassis.assert_called_once_with(
             self.root._conn, 'fake-chassis-id',
             redfish_version=self.root.redfish_version,
-            registries=mock_registries
+            registries=mock_lazy_registries
         )
 
     @mock.patch.object(chassis, 'ChassisCollection', autospec=True)
     @mock.patch.object(chassis, 'Chassis', autospec=True)
-    @mock.patch('sushy.Sushy.registries', autospec=True)
+    @mock.patch('sushy.Sushy.lazy_registries', autospec=True)
     def test_get_chassis_default_failure(
-            self, mock_registries, mock_chassis, mock_chassis_collection):
+            self, mock_lazy_registries, mock_chassis, mock_chassis_collection):
         self.root._standard_message_registries_path = None
         mock_members = mock_chassis_collection.return_value.get_members
         mock_members.return_value = []
@@ -192,7 +192,7 @@ class MainTestCase(base.TestCase):
         mock_chassis_collection.assert_called_once_with(
             self.root._conn, '/redfish/v1/Chassis',
             redfish_version=self.root.redfish_version,
-            registries=mock_registries
+            registries=mock_lazy_registries
         )
 
     @mock.patch.object(chassis, 'ChassisCollection', autospec=True)
@@ -200,41 +200,41 @@ class MainTestCase(base.TestCase):
         self.root.get_chassis_collection()
         chassis_collection_mock.assert_called_once_with(
             self.root._conn, '/redfish/v1/Chassis',
-            self.root.redfish_version, self.root.registries)
+            self.root.redfish_version, self.root.lazy_registries)
 
     @mock.patch.object(fabric, 'Fabric', autospec=True)
     def test_get_fabric(self, mock_fabric):
         self.root.get_fabric('fake-fabric-id')
         mock_fabric.assert_called_once_with(
             self.root._conn, 'fake-fabric-id',
-            self.root.redfish_version, self.root.registries)
+            self.root.redfish_version, self.root.lazy_registries)
 
     @mock.patch.object(fabric, 'FabricCollection', autospec=True)
     def test_get_fabric_collection(self, fabric_collection_mock):
         self.root.get_fabric_collection()
         fabric_collection_mock.assert_called_once_with(
             self.root._conn, '/redfish/v1/Fabrics',
-            self.root.redfish_version, self.root.registries)
+            self.root.redfish_version, self.root.lazy_registries)
 
     @mock.patch.object(manager, 'ManagerCollection', autospec=True)
     def test_get_manager_collection(self, ManagerCollection_mock):
         self.root.get_manager_collection()
         ManagerCollection_mock.assert_called_once_with(
             self.root._conn, '/redfish/v1/Managers',
-            self.root.redfish_version, self.root.registries)
+            self.root.redfish_version, self.root.lazy_registries)
 
     @mock.patch.object(manager, 'Manager', autospec=True)
     def test_get_manager(self, Manager_mock):
         self.root.get_manager('fake-manager-id')
         Manager_mock.assert_called_once_with(
             self.root._conn, 'fake-manager-id',
-            self.root.redfish_version, self.root.registries)
+            self.root.redfish_version, self.root.lazy_registries)
 
     @mock.patch.object(manager, 'ManagerCollection', autospec=True)
     @mock.patch.object(manager, 'Manager', autospec=True)
-    @mock.patch('sushy.Sushy.registries', autospec=True)
+    @mock.patch('sushy.Sushy.lazy_registries', autospec=True)
     def test_get_manager_default_ok(
-            self, mock_registries, mock_manager, mock_manager_collection):
+            self, mock_lazy_registries, mock_manager, mock_manager_collection):
         self.root._standard_message_registries_path = None
         mock_manager.path = 'fake-manager-id'
         mock_members = mock_manager_collection.return_value.get_members
@@ -243,18 +243,18 @@ class MainTestCase(base.TestCase):
         mock_manager_collection.assert_called_once_with(
             self.root._conn, '/redfish/v1/Managers',
             redfish_version=self.root.redfish_version,
-            registries=mock_registries
+            registries=mock_lazy_registries
         )
         mock_manager.assert_called_once_with(
             self.root._conn, 'fake-manager-id',
             redfish_version=self.root.redfish_version,
-            registries=mock_registries)
+            registries=mock_lazy_registries)
 
     @mock.patch.object(manager, 'ManagerCollection', autospec=True)
     @mock.patch.object(manager, 'Manager', autospec=True)
-    @mock.patch('sushy.Sushy.registries', autospec=True)
+    @mock.patch('sushy.Sushy.lazy_registries', autospec=True)
     def test_get_manager_default_failure(
-            self, mock_registries, mock_manager, mock_system_collection):
+            self, mock_lazy_registries, mock_manager, mock_system_collection):
         self.root._standard_message_registries_path = None
         mock_members = mock_system_collection.return_value.get_members
         mock_members.return_value = []
@@ -263,7 +263,7 @@ class MainTestCase(base.TestCase):
         mock_system_collection.assert_called_once_with(
             self.root._conn, '/redfish/v1/Managers',
             redfish_version=self.root.redfish_version,
-            registries=mock_registries
+            registries=mock_lazy_registries
         )
 
     @mock.patch.object(sessionservice, 'SessionService', autospec=True)
@@ -278,14 +278,14 @@ class MainTestCase(base.TestCase):
         self.root.get_session('asdf')
         mock_sess.assert_called_once_with(
             self.root._conn, 'asdf',
-            self.root.redfish_version, self.root.registries)
+            self.root.redfish_version, self.root.lazy_registries)
 
     @mock.patch.object(updateservice, 'UpdateService', autospec=True)
     def test_get_update_service(self, mock_upd_serv):
         self.root.get_update_service()
         mock_upd_serv.assert_called_once_with(
             self.root._conn, '/redfish/v1/UpdateService',
-            self.root.redfish_version, self.root.registries)
+            self.root.redfish_version, self.root.lazy_registries)
 
     @mock.patch.object(message_registry_file,
                        'MessageRegistryFileCollection',
@@ -303,7 +303,7 @@ class MainTestCase(base.TestCase):
         self.root.get_composition_service()
         mock_comp_ser.assert_called_once_with(
             self.root._conn, '/redfish/v1/CompositionService',
-            self.root.redfish_version, self.root.registries)
+            self.root.redfish_version, self.root.lazy_registries)
 
     def test__get_standard_message_registry_collection(self):
         registries = self.root._get_standard_message_registry_collection()
@@ -383,6 +383,13 @@ class MainTestCase(base.TestCase):
         registries = self.root.registries
         self.assertEqual({'RegistryA.2.0': mock_msg_reg1}, registries)
 
+    @mock.patch('sushy.Sushy.registries', autospec=True)
+    def test_lazy_registries(self, mock_registries):
+        registries = self.root.lazy_registries
+        self.assertEqual(0, mock_registries.__getitem__.call_count)
+        registries[1]
+        self.assertEqual(1, mock_registries.__getitem__.call_count)
+
 
 class BareMinimumMainTestCase(base.TestCase):
 
