@@ -14,19 +14,11 @@
 #    under the License.
 
 import collections
-
-# (rpittau) this allows usage of collection ABC abstract classes in both
-# Python 2.7 and Python 3.8+
-try:
-    collectionsAbc = collections.abc
-except AttributeError:
-    collectionsAbc = collections
+import functools
 
 import logging
 import threading
 
-import six
-
 from sushy import exceptions
 
 LOG = logging.getLogger(__name__)
@@ -220,7 +212,7 @@ def cache_it(res_accessor_method):
     """
     cache_attr_name = '_cache_' + res_accessor_method.__name__
 
-    @six.wraps(res_accessor_method)
+    @functools.wraps(res_accessor_method)
     def func_wrapper(res_selfie):
 
         cache_attr_val = getattr(res_selfie, cache_attr_name, None)
@@ -239,7 +231,7 @@ def cache_it(res_accessor_method):
 
         if isinstance(cache_attr_val, base.ResourceBase):
             cache_attr_val.refresh(force=False)
-        elif isinstance(cache_attr_val, collectionsAbc.Sequence):
+        elif isinstance(cache_attr_val, collections.abc.Sequence):
             for elem in cache_attr_val:
                 if isinstance(elem, base.ResourceBase):
                     elem.refresh(force=False)
@@ -268,7 +260,7 @@ def cache_clear(res_selfie, force_refresh, only_these=None):
     cache_attr_names = setdefaultattr(
         res_selfie, CACHE_ATTR_NAMES_VAR_NAME, set())
     if only_these is not None:
-        if not isinstance(only_these, collectionsAbc.Sequence):
+        if not isinstance(only_these, collections.abc.Sequence):
             raise TypeError("'only_these' must be a sequence.")
 
         cache_attr_names = cache_attr_names.intersection(
@@ -281,7 +273,7 @@ def cache_clear(res_selfie, force_refresh, only_these=None):
 
         if isinstance(cache_attr_val, base.ResourceBase):
             cache_attr_val.invalidate(force_refresh)
-        elif isinstance(cache_attr_val, collectionsAbc.Sequence):
+        elif isinstance(cache_attr_val, collections.abc.Sequence):
             for elem in cache_attr_val:
                 if isinstance(elem, base.ResourceBase):
                     elem.invalidate(force_refresh)
@@ -331,21 +323,9 @@ def synchronized(wrapped):
     """
     lock = threading.RLock()
 
-    @six.wraps(wrapped)
+    @functools.wraps(wrapped)
     def wrapper(*args, **kwargs):
         with lock:
             return wrapped(*args, **kwargs)
 
     return wrapper
-
-
-_REMOVE = frozenset(['password', 'x-auth-token'])
-
-
-def sanitize(item):
-    """Remove passwords from the item."""
-    if isinstance(item, dict):
-        return {key: ('***' if key.lower() in _REMOVE else sanitize(value))
-                for key, value in item.items()}
-    else:
-        return item
